@@ -1,7 +1,9 @@
+import traceback
 from collections import defaultdict
+from enum import Enum
 from functools import partial, wraps
-from inspect import isawaitable, isfunction, iscoroutinefunction
-from typing import Dict, Union
+from inspect import iscoroutinefunction, isfunction
+from typing import Dict, Mapping, Union
 
 from graphql import (
     GraphQLFieldResolver,
@@ -15,7 +17,7 @@ from graphql import (
     is_union_type,
 )
 
-from .utils import recursive_to_camel_case, to_camel_case
+from .utils import execute_async_function, recursive_to_snake_case, to_camel_case, to_snake_case
 
 FieldResolverMap = Dict[str, Dict[str, GraphQLFieldResolver]]
 TypeResolverMap = Dict[str, GraphQLTypeResolver]
@@ -32,28 +34,38 @@ def type_resolver(type_name: str):
     return wrap
 
 
-def field_resolver(type_name: str, func_or_field: Union[GraphQLFieldResolver, str] = None, to_camel: bool = True):
+def field_resolver(
+    type_name: str, func_or_field: Union[GraphQLFieldResolver, str] = None, print_exc: bool = True
+):
     def wrap(func: GraphQLFieldResolver):
         @wraps(func)
         def _resolver(*args, **kwargs):
-            result = func(*args, **kwargs)
-            if to_camel:
-                result = recursive_to_camel_case(result)
-            return result
+            kwargs = recursive_to_snake_case(kwargs)
+            if not print_exc:
+                return func(*args, **kwargs)
+
+            try:
+                return func(*args, **kwargs)
+            except Exception as exc:
+                traceback.print_exc()
+                raise exc
 
         @wraps(func)
         async def async_resolver(*args, **kwargs):
-            result = func(*args, **kwargs)
-            if isawaitable(result):
-                result = await result
-            if to_camel:
-                result = recursive_to_camel_case(result)
-            return result
+            kwargs = recursive_to_snake_case(kwargs)
+            if not print_exc:
+                return await execute_async_function(func, *args, **kwargs)
+
+            try:
+                return await execute_async_function(func, *args, **kwargs)
+            except Exception as exc:
+                traceback.print_exc()
+                raise exc
 
         if isinstance(func_or_field, str):
             name = to_camel_case(func_or_field or func.__name__)
         else:
-            name = func.__name__
+            name = to_camel_case(func.__name__)
 
         if iscoroutinefunction(func):
             field_resolver_map[type_name][name] = async_resolver
@@ -98,7 +110,7 @@ def register_field_resolvers(schema: GraphQLSchema):
         for name, field_resolver in field_resolvers.items():
             field = type_.fields.get(name)
             if not field:
-                return
+                continue
             if type_name == 'Subscription':
                 field.subscribe = field_resolver
             else:
@@ -108,3 +120,26 @@ def register_field_resolvers(schema: GraphQLSchema):
 def register_resolvers(schema: GraphQLSchema):
     register_field_resolvers(schema)
     register_type_resolvers(schema)
+
+
+def default_field_resolver(source, info, **args):
+    """Default field resolver.
+
+    If a resolve function is not given, then a default resolve behavior is used which
+    takes the property of the source object of the same name as the field and returns
+    it as the result, or if it's a function, returns the result of calling that function
+    while passing along args and context.
+
+    For dictionaries, the field names are used as keys, for all other objects they are
+    used as attribute names.
+    """
+    # Ensure source is a value for which property access is acceptable.
+    field_name = to_snake_case(info.field_name)
+    value = (
+        source.get(field_name) if isinstance(source, Mapping) else getattr(source, field_name, None)
+    )
+    if callable(value):
+        return value(info, **args)
+    if isinstance(value, Enum):
+        return value.value
+    return value
